==> owncloud-9.0.3.tgz: owncloud/apps/files_external/l10n/zh_CN.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "步骤 1 失败。异常：%s",
    "Step 2 failed. Exception: %s" : "步骤 2 失败。异常：%s",
    "External storage" : "外部存储",
    "Personal" : "个人",
    "System" : "系统",
    "Grant access" : "授权",
    "Access granted" : "权限已授予。",
    "Enable encryption" : "启用加密",
    "Never" : "从不",
    "Saved" : "已保存",
    "external-storage" : "外部存储",
    "Username" : "用户名",
    "Password" : "密码",
    "Save" : "保存",
    "Access key" : "Access key",
    "Secret key" : "Secret key",
    "None" : "无",
    "API key" : "API密匙",
    "Amazon S3" : "Amazon S3",
    "Port" : "端口",
    "Region" : "地区",
    "Enable SSL" : "启用 SSL",
    "Enable Path Style" : "启用 Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "远程子文件夹",
    "Secure https://" : "安全 https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "主机",
    "Secure ftps://" : "安全 ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "本地",
    "Location" : "地点",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "根路径",
    "SFTP with secret key login" : "包含secret key的SFTP",
    "Share" : "共享",
    "Domain" : "域名",
    "SMB / CIFS using OC login" : "SMB / CIFS 使用 OC 登录信息",
    "OpenStack Object Storage" : "OpenStack 对象存储",
    "<b>Note:</b> " : "<b>注意：</b>",
    "Name" : "名称",
    "Storage type" : "存储类型",
    "Scope" : "适用范围",
    "External Storage" : "外部存储",
    "Folder name" : "目录名称",
    "Authentication" : "认证",
    "Configuration" : "配置",
    "Available for" : "可用于",
    "Add storage" : "增加存储",
    "Advanced settings" : "高级选项",
    "Delete" : "删除",
    "Allow users to mount the following external storage" : "允许用户挂载以下外部存储",
    "Allow users to mount external storage" : "允许用户挂载外部存储",
    "Builtin" : "内置",
    "Enable previews" : "启用预览",
    "Enable sharing" : "启用分享",
    "External mount error" : "外部挂载错误",
    "Hostname" : "主机名",
    "Invalid mount point" : "无效的挂载点",
    "No external storage configured" : "未配置外部存储",
    "Public key" : "公钥",
    "RSA public key" : "RSA 公钥",
    "SMB / CIFS" : "SMB / CIFS",
    "Username and password" : "用户名和密码",
    "You can add external storages in the personal settings" : "您可以在个人设置中添加外部存储"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.3.tgz: owncloud/apps/files_external/l10n/zh_CN.js <==
OC.L10N.register(
    "files_external",
    {
    "Please provide a valid app key and secret." : "请提供有效的应用key和secret",
    "Step 1 failed. Exception: %s" : "步骤 1 失败。异常：%s",
    "Step 2 failed. Exception: %s" : "步骤 2 失败。异常：%s",
    "External storage" : "外部存储",
    "Dropbox App Configuration" : "Dropbox 应用配置",
    "Google Drive App Configuration" : "Google Drive 应用配置",
    "Personal" : "个人",
    "System" : "系统",
    "Grant access" : "授权",
    "Error configuring OAuth1" : "配置OAuth1时出错",
    "Error configuring OAuth2" : "配置OAuth2时出错",
    "Generate keys" : "生成密钥",
    "Error generating key pair" : "生成密钥时出错",
    "Saved" : "已保存",
    "There was an error with message: " : "发生错误：",
    "External mount error" : "外部挂载错误",
    "Username" : "用户名",
    "Password" : "密码",
    "Credentials saved" : "凭证已保存",
    "Credentials saving failed" : "凭证保存失败",
    "Save" : "保存",
    "Invalid mount point" : "无效的挂载点",
    "%s" : "%s",
    "Access key" : "Access key",
    "Secret key" : "Secret key",
    "API key" : "API密匙",
    "RSA public key" : "RSA 公钥",
    "Public key" : "公钥",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "主机名",
    "Port" : "端口",
    "Region" : "地区",
    "Enable SSL" : "启用 SSL",
    "Enable Path Style" : "启用 Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "远程子文件夹",
    "Secure https://" : "安全 https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "本地",
    "Location" : "地点",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "主机",
    "Root" : "根路径",
    "SFTP with secret key login" : "包含secret key的SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "共享",
    "Domain" : "域名",
    "SMB / CIFS using OC login" : "SMB / CIFS 使用 OC 登录信息",
    "OpenStack Object Storage" : "OpenStack 对象存储",
    "Service name" : "服务名称",
    "<b>Note:</b> " : "<b>注意：</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意：</b> PHP 中的 cURL 支持未启用或未安装。对 %s 的挂载无法进行。请联系系统管理员进行安装。",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意：</b>“%s”尚未安装。对 %s 的挂载无法进行。请联系系统管理员进行安装。",
    "No external storage configured" : "未配置外部存储",
    "Name" : "名称",
    "Storage type" : "存储类型",
    "Scope" : "适用范围",
    "Enable encryption" : "启用加密",
    "Enable previews" : "启用预览",
    "Enable sharing" : "启用分享",
    "Check for changes" : "检查更改",
    "Never" : "从不",
    "External Storage" : "外部存储",
    "Folder name" : "目录名称",
    "Authentication" : "认证",
    "Configuration" : "配置",
    "Available for" : "可用于",
    "Add storage" : "增加存储",
    "Advanced settings" : "高级选项",
    "Delete" : "删除",
    "Allow users to mount external storage" : "允许用户挂载外部存储",
    "Allow users to mount the following external storage" : "允许用户挂载以下外部存储"
},
"nplurals=1; plural=0;");
